@@ -12,11 +12,12 @@ from io import BytesIO
 def check(data, use_list=False):
     re = unpackb(packb(data), use_list=use_list)
     assert re == data
+    assert type(re) == type(data)
 
 def testPack():
     test_data = [
-            0, 1, 127, 128, 255, 256, 65535, 65536,
-            -1, -32, -33, -128, -129, -32768, -32769,
+            0, 1, 127, 128, 255, 256, 65535, 65536, 4294967295, 4294967296,
+            -1, -32, -33, -128, -129, -32768, -32769, -4294967296, -4294967297,
             1.0,
         b"", b"a", b"a"*31, b"a"*32,
         None, True, False,
